<?php

require_once 'DB.php';

/**
* Translation class
* 
* Class allows to store and retrieve all the strings on multilingual site in the database.
* Class connects to any database using PHP PEAR extension - so it needs PEAR to be installed to work 
* correctly.
* The object should be created for every page. While creation all the strings connected with specific page and the strings connected with all the pages on the site are loaded into variable, so access to them is quite fast and does not overload database server connection.
*
* @author Wojciech Zieliski <voyteck@caffe.com.pl>
* @version 1.2
* @access public
* @package Translation
*/

class Translation {

	/**
	* The translations are retrieved from this class object
	* @see Translation(), gstr(), getLangName(), getOtherLangs(), getMetaTags
	*/

	/**
	* Strings of the given page array - for fast access purposes
	* @var array string $Strings	
	*/
	var $Strings = array();

	/**
	* Page identifier
	* @var string $PageName		
	*/
	var $PageName = "";

	/**
	* Language identifier
	* @var string $LanguageID
	*/
	var $LanguageID = "";

	/**
	* Connection to database
	* @var object DB $db
	*/
	var $db;
	
	/**
	  * @param string $PageName		the page identifier. It identifies strings connected with specific page on the site
	  * @param string $LanguageID 		language id. All the languages are stored on the database on specific ID's.
	  * @param  string $pear_DSN			PEAR DSN string for database connection
	  */
	function Translation($PageName, $LanguageID, $pear_DSN) {
		$this->PageName = $PageName;
		$this->LanguageID = $LanguageID;
		$this->db = DB::connect($pear_DSN);
		if (DB::isError($this->db))
			die ($this->db->getMessage());
		$result = $this->db->query("SELECT string_id, string 
				FROM tr_strings_$LanguageID 
				WHERE page_id = '$PageName' OR page_id = ''");
		if (DB::isError($result))
			die ($result->getMessage());
		while ($row = $result->fetchRow())
			$this->Strings[$row[0]] = $row[1];
	}
	
	/**
	  * Translated string retrieval<br>
	  *
	  * Retrieves the strings basing on string indetifier
	  * 
	  * @param string $StringName		string identifier - unique for the page as well as for the strings, that are available on all the pages.
	  * @param array string $Params	string may be parametrized - and the paraters, that will be "inserted" into string may be typen into this array. It means, that &&1&& string will be replaced by 1st array element; string &&2&& will be replaced by 2nd array element; string &&3&& will be replaced by 3rd array element etc.
	  * @return string $String					retrieved string
	  */
	function gstr($StringName, $Params = array()) {
		$returnstring = $this->Strings[$StringName];
		$i = 0;
		if (count($Params) > 0) {
			while($Params[$i] != "") {
				$returnstring = str_replace("&&" . ++$i . "&&", $Params[$i-1], $returnstring);
			}
		}
		return $returnstring;
    }
	
	/**
	  * Active language name retrieval<br>
	  * 
	  * Retrieves the name of active language
	  * 
	  * @return string $LangName	current active language name or PEAR_ERROR object in case of problems
	  */
	function getLangName() {
		$result = $this->db->getRow("SELECT name
				FROM tr_langsavail
				WHERE lang_id = '" . $this->LanguageID . "'");
		if (DB::isError($result))
			return $result;
		return $result[0];
	}
	
	/**
	  * Other languages retrieval<br>
	  * 
	  * Retrieves names of all other languages, not the active.
	  * 
	  * @return array string $OtherLangs 2-dimensional array (0..)('id', 'name') for all the languages defined in DB but the current selected one. In case of DB error - returns PEAR_ERROR object.
 	  */
	function getOtherLangs() {
		$result = $this->db->query("SELECT lang_id, name
				FROM tr_langsavail
				WHERE lang_id <> '" . $this->LanguageID . "'");
		if (DB::isError($result))
			return $result;
		$i = 0;
		while($row = $result->fetchRow()) {
			$returnarray[$i]["id"] = $row[0];
			$returnarray[$i++]["name"] = $row[1];
		}
		return $returnarray;
	}
	
	/**
	  * META tags retrieval<br>
	  * 
	  * Retrievs the META tags that should be added on the top of translated page, so the translated characters will be correctly displayed on client's browser.
	  * 
	  * @return string $MetaTags string with configured in DB META tags for selected language. In case of DB error - returns PEAR_ERROR object.
	  */
	function getMetaTags() {
		$result = $this->db->getRow("SELECT metatags
				FROM tr_langsavail
				WHERE lang_id = '" . $this->LanguageID . "'");
		if (DB::isError($result))
			return $result;
		return $result[0];
	}
}


?>
